@@ -3,7 +3,7 @@ use strict;
 use Tk::Toplevel;
 
 use vars qw($VERSION @ISA);
-$VERSION = substr(q$Revision: 1.6 $, 10)+ 1; # so it's > 2.005
+$VERSION = substr(q$Revision: 1.8 $, 10)+ 1; # so it's > 2.005
 
 @ISA = qw(Tk::Toplevel);
 
@@ -21,20 +21,34 @@ sub Populate
 
  my $mbar = $w->Component('Menubar' => 'menubar');
  my $file = $mbar->Component('Menubutton' => 'file', '-text' => 'File', '-underline' => 0);
- $file->pack('-side' => 'left','-anchor' => 'w');
  $file->command('-label'=>'Open...', '-underline'=>0, '-command' => ['openfile',$w]);
  $file->command('-label'=>'Re-Read', '-underline'=>0, '-command' => ['reload',$p] );
  $file->command('-label'=>'Edit',    '-underline'=>0, '-command' => ['edit',$p] );
  $file->separator;
- $file->command('-label'=>'Quit',    '-underline'=>0, '-command' => ['quit',$w] );
+ $file->command('-label'=>'Close',    '-underline'=>0, '-command' => ['quit',$w] );
 
  my $help = $mbar->Component('Menubutton' => 'help', '-text' => 'Help', '-underline' => 0);
- $help->pack('-side' => 'right','-anchor' => 'e');
  # xxx restructure to not reference to tkpod
- $help->command('-label' => 'Usage...',       -command => sub{$w->parent->Pod(-file=>'tkpod')} );
- $help->command('-label' => 'Programming...', -command => sub{$w->parent->Pod(-file=>'Tk/Pod.pm')} );
+ $help->command('-label' => 'Usage...', -command => sub{
+		$w->parent->Pod(-file=>
+			( ($0 =~ /tkpod$/)
+				? $0       # fails with t/tkpod.t trick
+				: 'tkpod'  # fails when installed
+			)
+		)});
+ $help->command('-label' => 'Programming...', 
+		-command => sub{$w->parent->Pod(-file=>'Tk/Pod.pm')} );
 
- $mbar->pack('-side' => 'top', '-fill' => 'x', '-before' => ($w->packSlaves)[0]);
+  {
+     my $tkversion = $Tk::VERSION;
+     $tkversion =~ s/_//g;	# so 800.0_01 < 800.002
+     if ($tkversion lt '800.000')
+       {
+          $help->pack('-side'=>'right','-anchor'=>'e');
+          $file->pack('-side'=>'left','-anchor'=>'w');
+          $mbar->pack('-side'=>'top', '-fill'=>'x', '-before'=>($w->packSlaves)[0]);
+       }
+  }
  $w->Delegates('Menubutton' => $mbar, DEFAULT => $p);
  $w->ConfigSpecs('DEFAULT' => [$p]);
 
